Struct ZwlrDataControlDeviceV1
pub struct ZwlrDataControlDeviceV1 { /* private fields */ }wayland and Linux only.Expand description
manage a data device for a seat
This interface allows a client to manage a seat’s selection.
When the seat is destroyed, this object becomes inert.
See also the Event enum for this interface.
Implementations
impl ZwlrDataControlDeviceV1
impl ZwlrDataControlDeviceV1
pub fn set_selection(&self, source: Option<&ZwlrDataControlSourceV1>)
pub fn set_selection(&self, source: Option<&ZwlrDataControlSourceV1>)
copy data to the selection
This request asks the compositor to set the selection to the data from the source on behalf of the client.
The given source may not be used in any further set_selection or set_primary_selection requests. Attempting to use a previously used source is a protocol error.
To unset the selection, set the source to NULL.
pub fn destroy(&self)
pub fn destroy(&self)
destroy this data device
Destroys the data device object.
pub fn set_primary_selection(&self, source: Option<&ZwlrDataControlSourceV1>)
pub fn set_primary_selection(&self, source: Option<&ZwlrDataControlSourceV1>)
copy data to the primary selection
This request asks the compositor to set the primary selection to the data from the source on behalf of the client.
The given source may not be used in any further set_selection or set_primary_selection requests. Attempting to use a previously used source is a protocol error.
To unset the primary selection, set the source to NULL.
The compositor will ignore this request if it does not support primary selection.